planarity: Planarity-related graph algorithms
=============================================

Description
-----------

This code project provides a library for implementing graph algorithms
as well as implementations of several planarity-related graph
algorithms. The origin of this project is the reference implementation
for the Edge Addition Planarity Algorithm [1], which is now the fastest
and simplest linear-time method for planar graph embedding and planarity
obstruction isolation (i.e. Kuratowski subgraph isolation).

[1] http://dx.doi.org/10.7155/jgaa.00091

License
-------

New BSD License


Upstream Contact
----------------

-  https://github.com/graph-algorithms/edge-addition-planarity-suite/

-  John Boyer <John.Boyer.PhD@gmail.com>

Special Update/Build Instructions
---------------------------------

The tarballs can be found at
https://github.com/graph-algorithms/edge-addition-planarity-suite/releases
